import hou
import os
import sys
import subprocess
import secrets


def export_to_blender():
    job_var = hou.getenv("NS_JOB")
    blender_loc = hou.getenv("NS_BLENDER_LOCATION")
    
    if blender_loc:
        os.environ["PATH"] = blender_loc
        if not job_var:
            job_var = hou.getenv("JOB")
        
        selected_nodes = hou.selectedNodes()
        
        if selected_nodes:
            export_sop = selected_nodes[0]
            null_export_name = hou.ui.readInput("Blender Hook Name:", buttons=("OK", "Cancel"))
            export_null = export_sop.parent().createNode("null", "OUT_" + null_export_name[1])
            export_null.setPosition(export_sop.position() + hou.Vector2(0, -1))
            id = null_export_name[1] + "_" + str(secrets.token_hex(10))
            export_null.setComment("Blender Hook_ID: " + id)
            export_null.setGenericFlag(hou.nodeFlag.DisplayComment, True)
            export_null.setInput(0, export_sop)
            export_null.setDisplayFlag(True)
            
            export_loc = job_var + "/geo/__ns_Blender_Hooks/" + export_sop.parent().name() + "/" + null_export_name[1]

            ## parms ##
            tgroup = export_null.parmTemplateGroup()
            p = hou.StringParmTemplate("mesh_path", "Mesh Path", 1)
            p1 = hou.StringParmTemplate("blender_file_path", "Blender File Path", 1)
            p2 = hou.StringParmTemplate("blender_export_mesh", "Blender Export Mesh Path", 1)

            tgroup.append(p)
            tgroup.append(p1)
            tgroup.append(p2)

            export_null.setParmTemplateGroup(tgroup)
            export_null.setParms({
                "mesh_path": export_loc + "/" + id + ".obj",
                "blender_file_path": export_loc + "/" + id + ".blend",
                "blender_export_mesh": export_loc + "/" + id + "__BLENDER_EXPORT.obj"
            })

            try:
                if not os.path.isdir(export_loc):
                    os.makedirs(export_loc)  ## create Folder ##

                if not os.path.isfile(export_loc + "/" + id + ".obj"):
                    export_null.geometry().saveToFile(export_loc + "/" + id + ".obj")  ## export .abc ##
                else:
                    if hou.ui.displayMessage("A .abc file already exist., overwrite?", buttons=("Yes", "No")) == 0:
                        export_null.geometry().saveToFile(export_loc + "/" + id + ".obj")  ## export .abc ##
                        
                
                ## create start script ##
                start_script_loc = export_loc + "/blender_startup.py"
                py_file = open(start_script_loc, "w")
                py_cmd = '''import bpy
imported_object = bpy.ops.import_scene.obj(filepath="''' + export_loc + "/" + id + ".obj" + '''")
objs = bpy.data.objects
objs.remove(objs["Cube"], do_unlink=True)
bpy.ops.wm.save_as_mainfile(filepath="''' + export_loc + "/" + id + ".blend" + '''")
'''
                py_file.write(py_cmd)
                py_file.close()
                
                ## open blender ##
                if sys.platform == "darwin":  ## macOS ##
                    subprocess.Popen("blender --python " + start_script_loc)
                if sys.platform == "linux2":  ## Linux ##
                    subprocess.Popen("blender --python " + start_script_loc)
                if sys.platform == "win32":  ## Windows ##
                    subprocess.Popen("blender --python " + start_script_loc)


            except Exception as e:
                print(e)
                hou.ui.displayMessage("Cant export " + id + ".abc")
        else:
            hou.ui.displayMessage("Select a SOP-Node.")
    else:
        hou.ui.displayMessage("Set the Blender location first.")


export_to_blender()