import hou
import os
import sys
import getpass
import subprocess


def import_from_blender():
    blender_loc = hou.getenv("NS_BLENDER_LOCATION")
    
    if blender_loc:
        os.environ["PATH"] = blender_loc
        
        selected_nodes = hou.selectedNodes()
        
        if selected_nodes:
            export_sop = selected_nodes[0]
            blender_parm = export_sop.parm("blender_file_path").eval()

            if blender_parm:
                export_loc = os.path.dirname(blender_parm)
                tmp_parts = blender_parm.split("/")
                tmp_name_parts = tmp_parts[-1].split(".")
                
                ## create export script ##
                export_script_loc = export_loc + "/blender_export.py"
                py_file = open(export_script_loc, "w")
                py_cmd = '''import bpy
bpy.ops.wm.open_mainfile(filepath="''' + blender_parm + '''")
bpy.data.objects["''' + tmp_name_parts[0] +'''"].select_set(True)
bpy.ops.export_scene.obj(filepath="''' + export_loc + "/" + tmp_name_parts[0] + "__BLENDER_EXPORT.obj" + '''")
bpy.ops.wm.quit_blender()
                '''
                py_file.write(py_cmd)
                py_file.close()
    
                ## open blender ##
                if sys.platform == "darwin":  ## macOS ##
                    p = subprocess.Popen("blender -b --python " + export_script_loc)
                    p.wait()
                if sys.platform == "linux2":  ## Linux ##
                    p = subprocess.Popen("blender -b --python " + export_script_loc)
                    p.wait()
                if sys.platform == "win32":  ## Windows ##
                    p = subprocess.Popen("blender -b --python " + export_script_loc)
                    p.wait()
                
                file_node = hou.node(export_sop.parent().path() + "/" + export_sop.name().replace("OUT_", "IMPORT_"))
                
                if not file_node:
                    file_node = export_sop.parent().createNode("file", export_sop.name().replace("OUT_", "IMPORT_"))
                    file_node.setPosition(export_sop.position() + hou.Vector2(0, -2))
                    file_node.setParms({
                        "file": export_loc + "/" + tmp_name_parts[0] + "__BLENDER_EXPORT.obj"
                    })
                    file_node.setDisplayFlag(True)
                    file_node.setColor(hou.Color((0.576, 0.208, 0.475)))
                else:
                    file_node.parm("reload").pressButton()


            else:
                hou.ui.displayMessage("Parm missing. Select a SOP-Node::HookID - Null.")
        
        else:
            hou.ui.displayMessage("Select a SOP-Node::HookID - Null.")
    
    else:
        hou.ui.displayMessage("Set the Blender location first.")


import_from_blender()



